@@ -11,6 +11,12 @@ from setuptools import Extension
 
 USE_RELATIVE_PATHS = False
 
+COMPILER_DIRECTIVES = {'language_level': 3,
+                       'cdivision': True,
+                       'wraparound': False,
+                       'boundscheck': False,
+                       'initializedcheck': False,
+                       }
 
 
 DEVICES = {
@@ -99,9 +105,11 @@ def check_api_version(compiler, api_version_code, libraries, library_dirs, inclu
                     ld_path = os.pathsep.join(library_dirs) + os.pathsep + os.environ.get(path, "")
                     env[path] = ld_path
 
-            return float(check_output(check_api_program, env=env))
+            result = float(check_output(check_api_program, env=env))
+            print("    Automatic API version check succeeded.")
+            return result
         except Exception as e:
-            print("API version check failed: {}".format(e))
+            print("    API version check failed: {}".format(e))
             return 0.0
     finally:
         if old_stderr is not None:
@@ -111,11 +119,11 @@ def check_api_version(compiler, api_version_code, libraries, library_dirs, inclu
         shutil.rmtree(tmp_dir)
 
 
-def get_device_extensions_and_extras(library_dirs=None):
+def get_device_extensions_and_extras(library_dirs=None, include_dirs=None):
     library_dirs = [] if library_dirs is None else library_dirs
 
     cur_dir = os.path.dirname(os.path.realpath(__file__))
-    include_dirs = []
+    include_dirs = [] if include_dirs is None else include_dirs
 
     device_extras = dict()
 
@@ -172,10 +180,23 @@ def get_device_extensions_and_extras(library_dirs=None):
 
         device_extras.update(get_device_extras(compiler, dev_name, [params["lib"]], library_dirs, include_dirs))
         if "api_version_check_code" in params:
-            ver = check_api_version(compiler, params["api_version_check_code"], (params["lib"], ),
-                                    library_dirs, include_dirs)
-            device_extras[dev_name.upper() + "_API_VERSION"] = ver
-            print("    Detected {} v{}".format(dev_name.upper() + "_API_VERSION", ver))
+            env_name = dev_name.upper() + "_API_VERSION"
+            ver = os.getenv(env_name)
+            if ver is not None:
+                try:
+                    ver = float(ver)
+                except Exception as e:
+                    print("    Could not convert content of {} to float: {}".format(env_name, e))
+                    print("    Will now try to automatically detect API version.")
+                    ver = None
+            else:
+                print("    Environment variable {} is unset, try to automatically detect API version".format(env_name))
+
+            if ver is None:
+                ver = check_api_version(compiler, params["api_version_check_code"], (params["lib"], ),
+                                        library_dirs, include_dirs)
+            device_extras[env_name] = ver
+            print("    Using {}={}".format(env_name, ver))
 
         extension = get_device_extension(dev_name, [params["lib"]], library_dirs, include_dirs)
         result.append(extension)
@@ -240,6 +261,14 @@ if __name__ == "__main__":
     else:
         library_directories = None
 
+    if "-I" in sys.argv:
+        include_directories = sys.argv[sys.argv.index("-I") + 1].split(":")
+    else:
+        include_directories = []
+
+    import numpy as np
+    include_directories.append(np.get_include())
+
     cur_dir = os.path.dirname(os.path.realpath(__file__))
     os.chdir(os.path.join(cur_dir, "..", "..", ".."))
 
@@ -251,8 +280,10 @@ if __name__ == "__main__":
               file=sys.stderr)
         sys.exit(1)
 
-    dev_extensions, dev_extras = get_device_extensions_and_extras(library_dirs=library_directories)
+    dev_extensions, dev_extras = get_device_extensions_and_extras(library_dirs=library_directories,
+                                                                  include_dirs=include_directories)
     setup(
         name="urh",
-        ext_modules=cythonize(dev_extensions, force=True, compile_time_env=dev_extras),
+        ext_modules=cythonize(dev_extensions, force=True,
+                              compile_time_env=dev_extras, compiler_directives=COMPILER_DIRECTIVES),
     )
