@@ -1,3 +1,4 @@
+import logging
 import os
 
 import numpy as np
@@ -10,6 +11,7 @@ from urh.plugins.Plugin import SignalEditorPlugin
 from urh.signalprocessing.IQArray import IQArray
 from urh.ui.painting.SceneManager import SceneManager
 from urh.util.Formatter import Formatter
+from urh.util.Logger import logger
 
 
 class InsertSinePlugin(SignalEditorPlugin):
@@ -38,7 +40,11 @@ class InsertSinePlugin(SignalEditorPlugin):
     def dialog_ui(self) -> QDialog:
         if self.__dialog_ui is None:
             dir_name = os.path.dirname(os.readlink(__file__)) if os.path.islink(__file__) else os.path.dirname(__file__)
+
+            logging.getLogger().setLevel(logging.WARNING)
             self.__dialog_ui = uic.loadUi(os.path.realpath(os.path.join(dir_name, "insert_sine_dialog.ui")))
+            logging.getLogger().setLevel(logger.level)
+
             self.__dialog_ui.setAttribute(Qt.WA_DeleteOnClose)
             self.__dialog_ui.setModal(True)
             self.__dialog_ui.doubleSpinBoxAmplitude.setValue(self.__amplitude)
@@ -62,7 +68,7 @@ class InsertSinePlugin(SignalEditorPlugin):
 
     @property
     def amplitude(self) -> float:
-        return self.__amplitude * IQArray.min_max_for_dtype(self.original_data.dtype)[1]
+        return self.__amplitude
 
     @amplitude.setter
     def amplitude(self, value: float):
@@ -126,8 +132,8 @@ class InsertSinePlugin(SignalEditorPlugin):
             self.on_double_spin_box_sample_rate_editing_finished)
         self.dialog_ui.doubleSpinBoxNSamples.editingFinished.connect(self.on_spin_box_n_samples_editing_finished)
         self.dialog_ui.lineEditTime.editingFinished.connect(self.on_line_edit_time_editing_finished)
-        self.dialog_ui.btnAbort.clicked.connect(self.on_btn_abort_clicked)
-        self.dialog_ui.btnOK.clicked.connect(self.on_btn_ok_clicked)
+        self.dialog_ui.buttonBox.accepted.connect(self.on_button_box_accept)
+        self.dialog_ui.buttonBox.rejected.connect(self.on_button_box_reject)
         self.__dialog_ui.finished.connect(self.on_dialog_finished)
 
     def get_insert_sine_dialog(self, original_data, position, sample_rate=None, num_samples=None) -> QDialog:
@@ -154,10 +160,16 @@ class InsertSinePlugin(SignalEditorPlugin):
 
         QApplication.instance().setOverrideCursor(Qt.WaitCursor)
         self.__set_status_of_editable_elements(enabled=False)
+
         t = np.arange(0, self.num_samples) / self.sample_rate
-        arg = ((2 * np.pi * self.frequency * t + self.phase) * 1j).astype(np.complex64)
-        self.complex_wave = self.amplitude * np.exp(arg)  # type: np.ndarray
-        self.draw_data = np.insert(self.original_data[:, 0], self.position, self.complex_wave.real)
+        arg = 2 * np.pi * self.frequency * t + self.phase
+
+        self.complex_wave = np.empty(len(arg), dtype=np.complex64)
+        self.complex_wave.real = np.cos(arg)
+        self.complex_wave.imag = np.sin(arg)
+        self.complex_wave = IQArray(self.amplitude * self.complex_wave).convert_to(self.original_data.dtype)
+
+        self.draw_data = np.insert(self.original_data[:, 0], self.position, self.complex_wave[:, 0])
         y, h = self.dialog_ui.graphicsViewSineWave.view_rect().y(), self.dialog_ui.graphicsViewSineWave.view_rect().height()
         self.insert_indicator.setRect(self.position, y - h, self.num_samples, 2 * h + abs(y))
 
@@ -168,7 +180,7 @@ class InsertSinePlugin(SignalEditorPlugin):
 
     def __set_status_of_editable_elements(self, enabled: bool):
         for obj in ("doubleSpinBoxAmplitude", "doubleSpinBoxFrequency", "doubleSpinBoxPhase",
-                    "doubleSpinBoxSampleRate", "doubleSpinBoxNSamples", "lineEditTime", "btnOK"):
+                    "doubleSpinBoxSampleRate", "doubleSpinBoxNSamples", "lineEditTime", "buttonBox"):
             getattr(self.dialog_ui, obj).setEnabled(enabled)
 
     def set_time(self):
@@ -218,13 +230,13 @@ class InsertSinePlugin(SignalEditorPlugin):
             self.set_time()
 
     @pyqtSlot()
-    def on_btn_abort_clicked(self):
-        self.dialog_ui.close()
+    def on_button_box_reject(self):
+        self.dialog_ui.reject()
 
     @pyqtSlot()
-    def on_btn_ok_clicked(self):
+    def on_button_box_accept(self):
         self.insert_sine_wave_clicked.emit()
-        self.dialog_ui.close()
+        self.dialog_ui.accept()
 
     @pyqtSlot()
     def on_dialog_finished(self):
